@@ -1,6 +1,6 @@
 #!/usr/bin/env python
-#emacs: -*- mode: python-mode; py-indent-offset: 4; indent-tabs-mode: nil -*-
-#ex: set sts=4 ts=4 sw=4 et:
+# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
+# vi: set ft=python sts=4 ts=4 sw=4 et:
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the PyMVPA package for the
@@ -26,15 +26,14 @@ def main():
 
 
     # Load Haxby dataset example
-    haxby1path = 'data'
-    attrs = SampleAttributes(os.path.join(haxby1path,
+    attrs = SampleAttributes(os.path.join(pymvpa_dataroot,
                                           'attributes_literal.txt'))
-    haxby8 = NiftiDataset(samples=os.path.join(haxby1path,
+    haxby8 = NiftiDataset(samples=os.path.join(pymvpa_dataroot,
                                                'bold.nii.gz'),
                           labels=attrs.labels,
                           labels_map=True,
                           chunks=attrs.chunks,
-                          mask=os.path.join(haxby1path, 'mask.nii.gz'),
+                          mask=os.path.join(pymvpa_dataroot, 'mask.nii.gz'),
                           dtype=N.float32)
 
     # preprocess slightly
@@ -53,13 +52,13 @@ def main():
         [
         ((dummy2,
           "Dummy 2-class univariate with 2 useful features out of 100"),
-          clfs[:]),
+          clfswh[:]),
         ((pureMultivariateSignal(8, 3),
           "Dummy XOR-pattern"),
-          clfs['non-linear']),
+          clfswh['non-linear']),
         ((haxby8_no0,
           "Haxby 8-cat subject 1"),
-          clfs['multiclass']),
+          clfswh['multiclass']),
         ]:
         print "%s\n %s" % (datasetdescr, dataset.summary(idhash=False))
         print " Classifier                               " \
