@@ -1,5 +1,5 @@
-#emacs: -*- mode: python-mode; py-indent-offset: 4; indent-tabs-mode: nil -*-
-#ex: set sts=4 ts=4 sw=4 et:
+# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
+# vi: set ft=python sts=4 ts=4 sw=4 et:
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the PyMVPA package for the
@@ -15,10 +15,9 @@ mvpa.atlases module contains support for various atlases
 .. packagetree::
    :style: UML
 
-:group Base: BaseAtlas XMLBasedAtlas Label Level LabelsLevel
-:group Talairach: RumbaAtlas LabelsAtlas ReferencesAtlas
-:group Atlases from FSL: FSLAtlas FSLProbabilisticAtlas
-:group Exceptions: XMLAtlasException
+:group Base Implementations: base
+:group Atlases from FSL: fsl
+:group Helpers: warehouse transformation
 """
 
 __docformat__ = 'restructuredtext'
