@@ -1,5 +1,5 @@
-#emacs: -*- mode: python-mode; py-indent-offset: 4; indent-tabs-mode: nil -*-
-#ex: set sts=4 ts=4 sw=4 et:
+# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
+# vi: set ft=python sts=4 ts=4 sw=4 et:
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the PyMVPA package for the
@@ -16,7 +16,6 @@ from verbosity import verbose, debug; debug.active = [1,2,3]; debug(1, "blah")
 __docformat__ = 'restructuredtext'
 
 from sys import stdout, stderr
-from sets import Set
 # GOALS
 #  any logger should be able
 #   to log into a file or stdout/stderr
@@ -241,10 +240,13 @@ class SetLogger(Logger):
         from mvpa.base import verbose
         self.__active = []
         registered_keys = self.__registered.keys()
-        for item in list(Set(active)):
+        for item in list(set(active)):
             if item == '':
                 continue
             if isinstance(item, basestring):
+                if item in ['?', 'list', 'help']:
+                    self.print_registered(detailed=(item != '?'))
+                    raise SystemExit(0)
                 if item.upper() == "ALL":
                     verbose(2, "Enabling all registered debug handlers")
                     self.__active = registered_keys
@@ -277,7 +279,7 @@ class SetLogger(Logger):
                           % item_
             self.__active += toactivate
 
-        self.__active = list(Set(self.__active)) # select just unique ones
+        self.__active = list(set(self.__active)) # select just unique ones
         self.__maxstrlength = max([len(str(x)) for x in self.__active] + [0])
         if len(self.__active):
             verbose(2, "Enabling debug handlers: %s" % `self.__active`)
@@ -321,6 +323,20 @@ class SetLogger(Logger):
         self.active = value.split(",")
 
 
+    def print_registered(self, detailed=True):
+        print "Registered debug entries: ",
+        kd = self.registered
+        rks = sorted(kd.keys())
+        maxl = max([len(k) for k in rks])
+        if not detailed:
+            # short list
+            print ', '.join(rks)
+        else:
+            print
+            for k in rks:
+                print '%%%ds  %%s' % maxl % (k, kd[k])
+
+
     printsetid = property(fget=lambda self: self.__printsetid, \
                           fset=_setPrintsetid)
     active = property(fget=lambda self: self.__active, fset=_setActive)
@@ -356,7 +372,7 @@ if __debug__:
         Also strip .py at the end
         """
         base = basename(s).rstrip('py').rstrip('.')
-        if base in Set(['base', '__init__']):
+        if base in ['base', '__init__']:
             base = basename(dirname(s)) + '.' + base
         return base
 
@@ -461,10 +477,15 @@ if __debug__:
                 if DebugLogger._known_metrics.has_key(func):
                     func = DebugLogger._known_metrics[func]
                 else:
-                    raise ValueError, \
-                          "Unknown name %s for metric in DebugLogger" % \
-                          func + " Known metrics are " + \
-                          `DebugLogger._known_metrics.keys()`
+                    if func in ['?', 'list', 'help']:
+                        print 'Known debug metrics: ', \
+                              ', '.join(DebugLogger._known_metrics.keys())
+                        raise SystemExit(0)
+                    else:
+                        raise ValueError, \
+                              "Unknown name %s for metric in DebugLogger" % \
+                              func + " Known metrics are " + \
+                              `DebugLogger._known_metrics.keys()`
             elif isinstance(func, list):
                 self.__metrics = []     # reset
                 for item in func:
