@@ -1,5 +1,5 @@
-#emacs: -*- mode: python-mode; py-indent-offset: 4; indent-tabs-mode: nil -*-
-#ex: set sts=4 ts=4 sw=4 et:
+# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
+# vi: set ft=python sts=4 ts=4 sw=4 et:
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the PyMVPA package for the
@@ -15,10 +15,12 @@ mvpa.clfs module contains various classifiers
 .. packagetree::
    :style: UML
 
-:group Basic: classifier
-:group Specific Implementations: knn svm plr ridge smlr
-:group Internal Implementations: libsvm
-:group Utilities: transerror
+:group Base: base
+:group Meta Classifiers: meta
+:group Specific Implementations: knn svm _svmbase plr ridge smlr libsmlrc gpr blr
+:group External Interfaces: lars libsvmc sg
+:group Utilities: transerror model_selector stats kernel distance
+:group Warehouse of Classifiers: warehouse
 """
 
 __docformat__ = 'restructuredtext'
