@@ -32,6 +32,26 @@ from mvpa.base import warning
 if __debug__:
     from mvpa.base import debug
 
+class LearnerError(Exception):
+    """Base class for exceptions thrown by the learners (classifiers,
+    regressions)"""
+    pass
+
+class DegenerateInputError(LearnerError):
+    """Exception to be thrown by learners if input data is bogus, i.e. no
+    features or samples"""
+    pass
+
+class FailedToTrainError(LearnerError):
+    """Exception to be thrown whenever classifier fails to learn for
+    some reason"""
+    pass
+
+class FailedToPredictError(LearnerError):
+    """Exception to be thrown whenever classifier fails to provide predictions.
+    Usually happens if it was trained on degenerate data but without any complaints.
+    """
+    pass
 
 class Classifier(ClassWithCollections):
     """Abstract classifier class to be inherited by all classifiers
@@ -336,6 +356,8 @@ class Classifier(ClassWithCollections):
 
         TODO: think about proper re-implementation, without enrollment of deepcopy
         """
+        if __debug__:
+            debug("CLF", "Cloning %s#%s" % (self, id(self)))
         try:
             return deepcopy(self)
         except:
@@ -355,6 +377,10 @@ class Classifier(ClassWithCollections):
         Shouldn't be overridden in subclasses unless explicitly needed
         to do so
         """
+        if dataset.nfeatures == 0 or dataset.nsamples == 0:
+            raise DegenerateInputError(
+                "Cannot train classifier %s on degenerate data %s"
+                % (self, dataset))
         if __debug__:
             debug("CLF", "Training classifier %(clf)s on dataset %(dataset)s",
                   msgargs={'clf':self, 'dataset':dataset})
@@ -477,7 +503,7 @@ class Classifier(ClassWithCollections):
                     # it might be the values are pointing to result at
                     # the moment, so lets assure this silly way that
                     # they do not overlap
-                    states.values = states.values.copy()
+                    states.values = N.array(states.values, copy=True)
 
             trained_labels = self.trained_labels
             for i, value in enumerate(result):
