@@ -117,8 +117,10 @@ class GPR(Classifier):
             self._clf_internals += ['linear']
         else:
             self._clf_internals += ['non-linear']
-            if externals.exists('openopt'):
-                self._clf_internals += ['has_sensitivity']
+
+        if externals.exists('openopt') \
+               and not 'has_sensitivity' in self._clf_internals:
+            self._clf_internals += ['has_sensitivity']
 
         # No need to initialize state variables. Unless they got set
         # they would raise an exception self.predicted_variances =
@@ -478,7 +480,7 @@ class GPRLinearWeights(Sensitivity):
 
         if self.states.isEnabled('variances'):
             # super ugly formulas that can be quite surely improved:
-            tmp = N.linalg.inv(self._L)
+            tmp = N.linalg.inv(clf._L)
             Kyinv = Ndot(tmp.T, tmp)
             # XXX in such lengthy matrix manipulations you might better off
             #     using N.matrix where * is a matrix product
