@@ -1,5 +1,5 @@
-#emacs: -*- mode: python-mode; py-indent-offset: 4; indent-tabs-mode: nil -*-
-#ex: set sts=4 ts=4 sw=4 et:
+# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
+# vi: set ft=python sts=4 ts=4 sw=4 et:
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the PyMVPA package for the
@@ -12,7 +12,9 @@ __docformat__ = 'restructuredtext'
 
 import numpy as N
 
-import shogun.Classifier
+from mvpa.base import externals
+if externals.exists('shogun', raiseException=True):
+    import shogun.Classifier
 
 from mvpa.misc.state import StateVariable
 from mvpa.measures.base import Sensitivity
