@@ -224,7 +224,9 @@ class SVM(_SVM):
 
         self.__svm = None
         """Holds the trained svm."""
-
+        self.__svm_apply = None
+        """Compatibility convenience to bind to the classify/apply method
+           of __svm"""
         # Need to store original data...
         # TODO: keep 1 of them -- just __traindata or __traindataset
         # For now it is needed for computing sensitivities
@@ -412,6 +414,11 @@ class SVM(_SVM):
                 self.__svm = svm_impl_class(Cs[0], self.__kernel, labels)
                 self.__svm.set_epsilon(self.params.epsilon)
 
+            # To stay compatible with versions across API changes in sg 1.0.0
+            self.__svm_apply = hasattr(self.__svm, 'apply') \
+                               and self.__svm.apply \
+                               or  self.__svm.classify # the last one for old API
+
             # Set shrinking
             if self.params.isKnown('shrinking'):
                 shrinking = self.params.shrinking
@@ -465,7 +472,7 @@ class SVM(_SVM):
         # Report on training
         if (__debug__ and 'SG__' in debug.active) or \
            self.states.isEnabled('training_confusion'):
-            trained_labels = self.__svm.classify().get_labels()
+            trained_labels = self.__svm_apply().get_labels()
         else:
             trained_labels = None
 
@@ -541,7 +548,7 @@ class SVM(_SVM):
 
         # doesn't do any good imho although on unittests helps tiny bit... hm
         #self.__svm.init_kernel_optimization()
-        values_ = self.__svm.classify()
+        values_ = self.__svm_apply()
         if values_ is None:
             raise RuntimeError, "We got empty list of values from %s" % self
 
@@ -619,6 +626,7 @@ class SVM(_SVM):
                     if self.__svm is not None:
                         del self.__svm
                         self.__svm = None
+                        self.__svm_apply = None
 
                     if self.__traindata is not None:
                         # Let in for easy demonstration of the memory leak in shogun
