@@ -1,5 +1,5 @@
-#emacs: -*- mode: python-mode; py-indent-offset: 4; indent-tabs-mode: nil -*-
-#ex: set sts=4 ts=4 sw=4 et:
+# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
+# vi: set ft=python sts=4 ts=4 sw=4 et:
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the PyMVPA package for the
@@ -10,16 +10,16 @@
 
 __docformat__ = 'restructuredtext'
 
-
 import numpy as N
 
+from mvpa.base import warning, externals
 from mvpa.clfs.base import Classifier
 from mvpa.measures.base import Sensitivity
 from mvpa.misc.exceptions import ConvergenceError
-from mvpa.misc.state import StateVariable, Parametrized
 from mvpa.misc.param import Parameter
+from mvpa.misc.state import StateVariable
 from mvpa.misc.transformers import SecondAxisMaxOfAbs
-from mvpa.base import warning, externals
+
 
 _DEFAULT_IMPLEMENTATION = "Python"
 if externals.exists('ctypes'):
@@ -55,13 +55,14 @@ class SMLR(Classifier):
     """Sparse Multinomial Logistic Regression `Classifier`.
 
     This is an implementation of the SMLR algorithm published in
-    Krishnapuram et al. (2005, IEEE Transactions on Pattern Analysis
-    and Machine Intelligence).  Be sure to cite that article if you
-    use this for your work.
+    :ref:`Krishnapuram et al., 2005 <KCF+05>` (2005, IEEE Transactions
+    on Pattern Analysis and Machine Intelligence).  Be sure to cite
+    that article if you use this classifier for your work.
     """
 
     _clf_internals = [ 'smlr', 'linear', 'has_sensitivity', 'binary',
-                       'multiclass', 'does_feature_selection' ] # later 'kernel-based'?
+                       'multiclass', 'does_feature_selection' ]
+                     # XXX: later 'kernel-based'?
 
     lm = Parameter(.1, min=1e-10, allowedtype='float',
              doc="""The penalty term lambda.  Larger values will give rise to
@@ -73,7 +74,7 @@ class SMLR(Classifier):
              lead to tighter convergence.""")
 
     resamp_decay = Parameter(0.5, allowedtype='float', min=0.0, max=1.0,
-             doc="""Rate of decay in the probability of resampling a zero weight.
+             doc="""Decay rate in the probability of resampling a zero weight.
              1.0 will immediately decrease to the min_resamp from 1.0, 0.0
              will never decrease from 1.0.""")
 
@@ -96,7 +97,8 @@ class SMLR(Classifier):
             note that the convergence rate may be different, but convergence
             point is the same.""")
 
-    implementation = Parameter(_DEFAULT_IMPLEMENTATION, allowedtype='basestring',
+    implementation = Parameter(_DEFAULT_IMPLEMENTATION,
+             allowedtype='basestring',
              choices=["C", "Python"],
              doc="""Use C or Python as the implementation of
              stepwise_regression. C version brings significant speedup thus is
@@ -106,6 +108,14 @@ class SMLR(Classifier):
              doc="""Seed to be used to initialize random generator, might be
              used to replicate the run""")
 
+    unsparsify = Parameter(False, allowedtype='bool',
+             doc="""***EXPERIMENTAL*** Whether to unsparsify the weights via
+             regression. Note that it likely leads to worse classifier
+             performance, but more interpretable weights.""")
+
+    std_to_keep = Parameter(2.0, allowedtype='float',
+             doc="""Standard deviation threshold of weights to keep when
+             unsparsifying.""")
 
     def __init__(self, **kwargs):
         """Initialize an SMLR classifier.
@@ -275,12 +285,7 @@ class SMLR(Classifier):
         # calcualte the log likelihoods and posteriors for the training data
         #log_likelihood = x
 
-#        if __debug__:
-#            debug("SMLR_", \
-#                  "SMLR converged after %d steps. Error: %g" % \
-#                  (cycles, XXX))
-
-#        print 'cycles=%d ; wasted basis=%g\n' % (cycles, wasted_basis/((M-1)*nd))
+        return cycles
 
 
     def _train(self, dataset):
@@ -379,31 +384,86 @@ class SMLR(Classifier):
                   "More than %d Iterations without convergence" % \
                   (self.params.maxiter)
 
+        # see if unsparsify the weights
+        if self.params.unsparsify:
+            # unsparsify
+            w = self._unsparsify_weights(X, w)
+
         # save the weights
         self.__weights_all = w
         self.__weights = w[:dataset.nfeatures, :]
 
         if self.states.isEnabled('feature_ids'):
-            self.feature_ids = N.where(N.max(N.abs(w[:dataset.nfeatures,:]), axis=1)>0)[0]
+            self.feature_ids = N.where(N.max(N.abs(w[:dataset.nfeatures, :]),
+                                             axis=1)>0)[0]
 
         # and a bias
         if self.params.has_bias:
             self.__biases = w[-1, :]
 
         if __debug__:
-            debug('SMLR', "train finished in %s cycles on data.shape=%s " %
-                  (`cycles`, `X.shape`) +
+            debug('SMLR', "train finished in %d cycles on data.shape=%s " %
+                  (cycles, X.shape) +
                   "min:max(data)=%f:%f, got min:max(w)=%f:%f" %
                   (N.min(X), N.max(X), N.min(w), N.max(w)))
 
+    def _unsparsify_weights(self, samples, weights):
+        """Unsparsify weights via least squares regression."""
+        # allocate for the new weights
+        new_weights = N.zeros(weights.shape, dtype=N.double)
+
+        # get the sample data we're predicting and the sum squared
+        # total variance
+        b = samples
+        sst = N.power(b - b.mean(0),2).sum(0)
+
+        # loop over each column
+        for i in range(weights.shape[1]):
+            w = weights[:,i]
+
+            # get the nonzero ind
+            ind = w!=0
+
+            # get the features with non-zero weights
+            a = b[:,ind]
+
+            # predict all the data with the non-zero features
+            betas = N.linalg.lstsq(a,b)[0]
+
+            # determine the R^2 for each feature based on the sum
+            # squared prediction error
+            f = N.dot(a,betas)
+            sse = N.power((b-f),2).sum(0)
+            rsquare = N.zeros(sse.shape,dtype=sse.dtype)
+            gind = sst>0
+            rsquare[gind] = 1-(sse[gind]/sst[gind])
+
+            # derrive new weights by combining the betas and weights
+            # scaled by the rsquare
+            new_weights[:,i] = N.dot(w[ind],betas)*rsquare
+
+        # take the tails
+        tozero = N.abs(new_weights) < self.params.std_to_keep*N.std(new_weights)
+        orig_zero = weights==0.0
+        if orig_zero.sum() < tozero.sum():
+            # should not end up with fewer than start
+            tozero = orig_zero
+        new_weights[tozero] = 0.0
+
+        debug('SMLR_', "Start nonzero: %d; Finish nonzero: %d" % \
+              ((weights!=0).sum(), (new_weights!=0).sum()))
+        
+        return new_weights
+
 
     def _getFeatureIds(self):
+        """Return ids of the used features
+        """
         return N.where(N.max(N.abs(self.__weights), axis=1)>0)[0]
 
 
     def _predict(self, data):
-        """
-        Predict the output for the provided data.
+        """Predict the output for the provided data.
         """
         # see if we are adding a bias term
         if self.params.has_bias:
@@ -436,7 +496,8 @@ class SMLR(Classifier):
         # generate predictions
         predictions = N.asarray([self.__ulabels[N.argmax(vals)]
                                  for vals in values])
-        # no need to assign state variable here -- would be done in Classifier._postpredict anyway
+        # no need to assign state variable here -- would be done
+        # in Classifier._postpredict anyway
         #self.predictions = predictions
 
         return predictions
@@ -468,6 +529,7 @@ class SMLRWeights(Sensitivity):
 
     _LEGAL_CLFS = [ SMLR ]
 
+
     def _call(self, dataset=None):
         """Extract weights from SMLR classifier.
 
