@@ -14,7 +14,6 @@ import mvpa.support.copy as copy
 
 import numpy as N
 
-from sets import Set
 from StringIO import StringIO
 from math import log10, ceil
 
@@ -262,6 +261,14 @@ class ROCCurve(object):
         Nlabels = len(labels)
         sets = self._sets
 
+        # Handle degenerate cases politely
+        if Nlabels < 2:
+            warning("ROC was asked to be evaluated on data with %i"
+                    " labels which is a degenerate case.")
+            self._ROCs = []
+            self._aucs = []
+            return
+
         # take sets which have values in the shape we can handle
         def _checkValues(set_):
             """Check if values are 'acceptable'"""
@@ -499,17 +506,17 @@ class ConfusionMatrix(SummaryStatistics):
         try:
             # figure out what labels we have
             labels = \
-                list(reduce(lambda x, y: x.union(Set(y[0]).union(Set(y[1]))),
+                list(reduce(lambda x, y: x.union(set(y[0]).union(set(y[1]))),
                             self.sets,
-                            Set(self.__labels)))
+                            set(self.__labels)))
         except:
             labels = self.__labels
 
         # Check labels_map if it was provided if it covers all the labels
         labels_map = self.__labels_map
         if labels_map is not None:
-            labels_set = Set(labels)
-            map_labels_set = Set(labels_map.values())
+            labels_set = set(labels)
+            map_labels_set = set(labels_map.values())
 
             if not map_labels_set.issuperset(labels_set):
                 warning("Provided labels_map %s is not coherent with labels "
@@ -797,13 +804,13 @@ class ConfusionMatrix(SummaryStatistics):
 
         if labels_order is not None:
             labels_order_filtered = filter(lambda x:x is not None, labels_order)
-            labels_order_filtered_set = Set(labels_order_filtered)
+            labels_order_filtered_set = set(labels_order_filtered)
             # Verify if all labels provided in labels
-            if Set(labels) == labels_order_filtered_set:
+            if set(labels) == labels_order_filtered_set:
                 # We were provided numerical (most probably) set
                 labels_plot = labels_order
             elif len(labels_rev) \
-                     and Set(labels_rev) == labels_order_filtered_set:
+                     and set(labels_rev) == labels_order_filtered_set:
                 # not clear if right whenever there were multiple labels
                 # mapped into the same
                 labels_plot = []
@@ -1262,8 +1269,8 @@ class ClassifierError(ClassWithCollections):
 
         if self.__clf.states.isEnabled('trained_labels') and \
                not testdataset is None:
-            newlabels = Set(testdataset.uniquelabels) \
-                        - Set(self.__clf.trained_labels)
+            newlabels = set(testdataset.uniquelabels) \
+                        - set(self.__clf.trained_labels)
             if len(newlabels)>0:
                 warning("Classifier %s wasn't trained to classify labels %s" %
                         (`self.__clf`, `newlabels`) +
@@ -1308,6 +1315,12 @@ class ClassifierError(ClassWithCollections):
         return error
 
 
+    def untrain(self):
+        """Untrain the *Error which relies on the classifier
+        """
+        self.clf.untrain()
+
+
     @property
     def clf(self):
         return self.__clf
@@ -1367,7 +1380,7 @@ class TransferError(ClassifierError):
 
         return out
 
-
+    # XXX: TODO: unify naming? test/train or with ing both
     def _call(self, testdataset, trainingdataset=None):
         """Compute the transfer error for a certain test dataset.
 
@@ -1424,7 +1437,7 @@ class TransferError(ClassifierError):
         if states.isEnabled('samples_error'):
             samples_error = []
             for i, p in enumerate(predictions):
-                samples_error.append(self.__errorfx(p, testdataset.labels[i]))
+                samples_error.append(self.__errorfx([p], testdataset.labels[i:i+1]))
 
             states.samples_error = dict(zip(testdataset.origids, samples_error))
 
@@ -1507,6 +1520,6 @@ class ConfusionBasedError(ClassifierError):
     def _call(self, testdata, trainingdata=None):
         """Extract transfer error. Nor testdata, neither trainingdata is used
         """
-        confusion = self.clf.states.getvalue(self.__confusion_state)
+        confusion = self.clf.states[self.__confusion_state].value
         self.confusion = confusion
         return confusion.error
