@@ -11,7 +11,6 @@
 
 __docformat__ = 'restructuredtext'
 
-from sets import Set
 import operator
 
 # Define sets of classifiers
@@ -19,6 +18,7 @@ from mvpa.clfs.meta import FeatureSelectionClassifier, SplitClassifier, \
      MulticlassClassifier
 from mvpa.clfs.smlr import SMLR
 from mvpa.clfs.knn import kNN
+from mvpa.clfs.gnb import GNB
 from mvpa.clfs.kernel import KernelLinear, KernelSquaredExponential
 
 # Helpers
@@ -35,7 +35,8 @@ _KNOWN_INTERNALS = [ 'knn', 'binary', 'svm', 'linear',
         'smlr', 'does_feature_selection', 'has_sensitivity',
         'multiclass', 'non-linear', 'kernel-based', 'lars',
         'regression', 'libsvm', 'sg', 'meta', 'retrainable', 'gpr',
-        'notrain2predict', 'ridge', 'blr', 'gnpp', 'enet', 'glmnet']
+        'notrain2predict', 'ridge', 'blr', 'gnpp', 'enet', 'glmnet',
+        'gnb', 'plr']
 
 class Warehouse(object):
     """Class to keep known instantiated classifiers
@@ -58,9 +59,9 @@ class Warehouse(object):
             matches={'binary':['regression']}, would allow to provide
             regressions also if 'binary' was requested
             """
-        self._known_tags = Set(known_tags)
+        self._known_tags = set(known_tags)
         self.__items = []
-        self.__keys = Set()
+        self.__keys = set()
         if matches is None:
             matches = {}
         self.__matches = matches
@@ -74,7 +75,7 @@ class Warehouse(object):
             args = []
 
         # lets remove optional modifier '!'
-        dargs = Set([str(x).lstrip('!') for x in args]).difference(
+        dargs = set([str(x).lstrip('!') for x in args]).difference(
             self._known_tags)
 
         if len(dargs)>0:
@@ -119,7 +120,7 @@ class Warehouse(object):
             if len(item._clf_internals) == 0:
                 raise ValueError, "Cannot register %s " % item + \
                       "which has empty _clf_internals"
-            clf_internals = Set(item._clf_internals)
+            clf_internals = set(item._clf_internals)
             if clf_internals.issubset(self._known_tags):
                 self.__items.append(item)
                 self.__keys |= clf_internals
@@ -168,7 +169,7 @@ clfswh += \
 
 if externals.exists('libsvm'):
     from mvpa.clfs import libsvmc as libsvm
-    clfswh._known_tags.union_update(libsvm.SVM._KNOWN_IMPLEMENTATIONS.keys())
+    clfswh._known_tags.update(libsvm.SVM._KNOWN_IMPLEMENTATIONS.keys())
     clfswh += [libsvm.SVM(descr="libsvm.LinSVM(C=def)", probability=1),
              libsvm.SVM(
                  C=-10.0, descr="libsvm.LinSVM(C=10*def)", probability=1),
@@ -188,7 +189,7 @@ if externals.exists('libsvm'):
              ]
 
     # regressions
-    regrswh._known_tags.union_update(['EPSILON_SVR', 'NU_SVR'])
+    regrswh._known_tags.update(['EPSILON_SVR', 'NU_SVR'])
     regrswh += [libsvm.SVM(svm_impl='EPSILON_SVR', descr='libsvm epsilon-SVR',
                          regression=True),
               libsvm.SVM(svm_impl='NU_SVR', descr='libsvm nu-SVR',
@@ -196,7 +197,7 @@ if externals.exists('libsvm'):
 
 if externals.exists('shogun'):
     from mvpa.clfs import sg
-    clfswh._known_tags.union_update(sg.SVM._KNOWN_IMPLEMENTATIONS)
+    clfswh._known_tags.update(sg.SVM._KNOWN_IMPLEMENTATIONS)
 
     # some classifiers are not yet ready to be used out-of-the-box in
     # PyMVPA, thus we don't populate warehouse with their instances
@@ -239,10 +240,13 @@ if externals.exists('shogun'):
 #                   % impl, svm_impl=impl, kernel_type="sigmoid"),
             ]
 
-    for impl in ['libsvr', 'krr']:# \
+    _optional_regressions = []
+    if externals.exists('shogun.krr'):
+        _optional_regressions += ['krr']
+    for impl in ['libsvr'] + _optional_regressions:# \
         # XXX svrlight sucks in SG -- dont' have time to figure it out
         #+ ([], ['svrlight'])['svrlight' in sg.SVM._KNOWN_IMPLEMENTATIONS]:
-        regrswh._known_tags.union_update([impl])
+        regrswh._known_tags.update([impl])
         regrswh += [ sg.SVM(svm_impl=impl, descr='sg.LinSVMR()/%s' % impl,
                           regression=True),
                    #sg.SVM(svm_impl=impl, kernel_type='RBF',
@@ -313,6 +317,19 @@ clfswh += \
         descr="kNN on 50(ANOVA)")
 
 
+# GNB
+clfswh += GNB(descr="GNB()")
+clfswh += GNB(common_variance=True, descr="GNB(common_variance=True)")
+clfswh += GNB(prior='uniform', descr="GNB(prior='uniform')")
+clfswh += \
+    FeatureSelectionClassifier(
+        GNB(),
+        SensitivityBasedFeatureSelection(
+           OneWayAnova(),
+           FractionTailSelector(0.05, mode='select', tail='upper')),
+        descr="GNB on 5%(ANOVA)")
+
+
 # GPR
 if externals.exists('scipy'):
     from mvpa.clfs.gpr import GPR
@@ -325,6 +342,11 @@ if externals.exists('scipy'):
 from mvpa.clfs.blr import BLR
 clfswh += BLR(descr="BLR()")
 
+#PLR
+from mvpa.clfs.plr import PLR
+clfswh += PLR(descr="PLR()")
+if externals.exists('scipy'):
+    clfswh += PLR(reduced=0.05, descr="PLR(reduced=0.01)")
 
 # SVM stuff
 
