@@ -1,5 +1,5 @@
-#emacs: -*- mode: python-mode; py-indent-offset: 4; indent-tabs-mode: nil -*-
-#ex: set sts=4 ts=4 sw=4 et:
+# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
+# vi: set ft=python sts=4 ts=4 sw=4 et:
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the PyMVPA package for the
@@ -16,7 +16,9 @@ from mvpa.base import warning
 from mvpa.base.dochelpers import enhancedDocString
 from mvpa.mappers.base import ProjectionMapper
 
-from mdp.nodes import NIPALSNode
+import mvpa.base.externals as externals
+if externals.exists('mdp', raiseException=True):
+    from mdp.nodes import NIPALSNode
 
 
 class PCAMapper(ProjectionMapper):
@@ -40,8 +42,8 @@ class PCAMapper(ProjectionMapper):
         """
         samples = dataset.samples
         dtype = samples.dtype
-        if str(samples.dtype).startswith('uint') \
-               or str(samples.dtype).startswith('int'):
+        if str(dtype).startswith('uint') \
+               or str(dtype).startswith('int'):
                 warning("PCA: input data is in integers. " + \
                         "MDP's NIPALSNode operates only on floats, thus "+\
                         "coercing to double")
