@@ -1,5 +1,5 @@
-#emacs: -*- mode: python-mode; py-indent-offset: 4; indent-tabs-mode: nil -*-
-#ex: set sts=4 ts=4 sw=4 et:
+# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
+# vi: set ft=python sts=4 ts=4 sw=4 et:
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the PyMVPA package for the
@@ -17,6 +17,8 @@ has prefix opts (e.g. `opts.common`).
 Option name should be camelbacked version of .dest for the option.
 """
 
+import mvpa
+
 # TODO? all options (opt*) might migrate to respective module? discuss
 from optparse import OptionParser, Option, OptionGroup, OptionConflictError
 
@@ -27,7 +29,7 @@ from mvpa.base import verbose, externals
 # groups, since otherwise it is impossible to use them without using
 # the whole group. May be we should make some late creation of the
 # groups -- ie only if user requests a group, options are added to it.
-from mvpa.misc import copy
+from mvpa.support import copy
 
 class Options(object):
     """Just a convinience placeholder for all available options
@@ -79,7 +81,10 @@ class OptionGroups(object):
 # Conflict hanlder to resolve situation that we have the same option added
 # to some group and also available 'freely'
 #
-parser = OptionParser(add_help_option=False,
+# set default version string, otherwise '--version' option is not enabled
+# can be overwritten later on by assigning to `parser.version`
+parser = OptionParser(version="%prog",
+                      add_help_option=False,
                       conflict_handler="error")
 
 
@@ -92,6 +97,8 @@ opts = OptionGroups(parser)
 def _verboseCallback(option, optstr, value, parser):
     """Callback for -v|--verbose cmdline option
     """
+    if __debug__:
+        debug("CMDLINE", "Setting verbose.level to %s" % str(value))
     verbose.level = value
     optstr = optstr                     # pylint shut up
     setattr(parser.values, option.dest, value)
