@@ -14,10 +14,11 @@ __docformat__ = 'restructuredtext'
 import numpy as N
 import mvpa.support.copy as copy
 from mvpa.base.dochelpers import enhancedDocString
-from sets import Set
 from re import sub as re_sub
 from mvpa.base import warning
 
+from mvpa.misc.support import Event
+
 if __debug__:
     from mvpa.base import debug
 
@@ -161,9 +162,12 @@ class ColumnData(dict):
 
         Is used for automatically added properties to the class.
 
-        :raises: ValueError, if `key` is not known to given instance
+        :Raises:
+          ValueError:
+            If `key` is not known to given instance
 
-        :return: value if `key` is known
+        :Returns:
+          Value if `key` is known
         """
         if self.has_key(key):
             return self[key]
@@ -303,18 +307,22 @@ class ColumnData(dict):
     def tofile(self, filename, header=True, header_order=None, sep=' '):
         """Write column data to a text file.
 
-        :Parameter:
-          filename: Think about it!
-          header: If `True` a column header is written, using the column
-                   keys. If `False` no header is written.
-          header_order: If it is a list of strings, they will be used instead
-                          of simply asking for the dictionary keys. However
-                          these strings must match the dictionary keys in number
-                          and identity. This argument type can be used to
-                          determine the order of the columns in the output file.
-                          The default value is `None`. In this case the columns
-                          will be in an arbitrary order.
-          sep: String that is written as a separator between to data columns.
+        :Parameters:
+          filename : basestring
+            Target filename
+          header : bool
+            If `True` a column header is written, using the column
+            keys. If `False` no header is written.
+          header_order : None or list of basestring
+            If it is a list of strings, they will be used instead
+            of simply asking for the dictionary keys. However
+            these strings must match the dictionary keys in number
+            and identity. This argument type can be used to
+            determine the order of the columns in the output file.
+            The default value is `None`. In this case the columns
+            will be in an arbitrary order.
+          sep : basestring
+            String that is written as a separator between to data columns.
         """
         # XXX do the try: except: dance
         file_ = open(filename, 'w')
@@ -326,8 +334,8 @@ class ColumnData(dict):
             else:
                 # use stored order + newly added keys at the last columns
                 col_hdr = self._header_order + \
-                          list(Set(self.keys()).difference(
-                                                Set(self._header_order)))
+                          list(set(self.keys()).difference(
+                                                set(self._header_order)))
         else:
             if not len(header_order) == self.getNColumns():
                 raise ValueError, 'Header list does not match number of ' \
@@ -369,19 +377,27 @@ class SampleAttributes(ColumnData):
     """Read and write PyMVPA sample attribute definitions from and to text
     files.
     """
-    def __init__(self, source, literallabels=False):
+    def __init__(self, source, literallabels=False, header=None):
         """Read PyMVPA sample attributes from disk.
 
-        :Parameter:
-          source: filename of an atrribute file
+        :Parameters:
+          source: basestring
+            Filename of an atrribute file
+          literallabels: bool
+            Either labels are given as literal strings
+          header: None or bool or list of str
+            If None, ['labels', 'chunks'] is assumed. Otherwise the same
+            behavior as of `ColumnData`
         """
         if literallabels:
             dtypes = [str, float]
         else:
             dtypes = float
 
+        if header is None:
+            header = ['labels', 'chunks']
         ColumnData.__init__(self, source,
-                            header=['labels', 'chunks'],
+                            header=header,
                             sep=None, dtype=dtypes)
 
 
@@ -400,6 +416,56 @@ class SampleAttributes(ColumnData):
         return self.getNRows()
 
 
+    def toEvents(self, **kwargs):
+        """Convert into a list of `Event` instances.
+
+        Each change in the label or chunks value is taken as a new event onset.
+        The length of an event is determined by the number of identical
+        consecutive label-chunk combinations. Since the attributes list has no
+        sense of absolute timing, both `onset` and `duration` are determined and
+        stored in #samples units.
+
+        :Parameters:
+          kwargs
+            Any keyword arugment provided would be replicated, through all
+            the entries.
+        """
+        events = []
+        prev_onset = 0
+        old_comb = None
+        duration = 1
+        # over all samples
+        for r in xrange(self.nrows):
+            # the label-chunk combination
+            comb = (self.labels[r], self.chunks[r])
+
+            # check if things changed
+            if not comb == old_comb:
+                # did we ever had an event
+                if not old_comb is None:
+                    events.append(
+                        Event(onset=prev_onset, duration=duration,
+                              label=old_comb[0], chunk=old_comb[1], **kwargs))
+                    # reset duration for next event
+                    duration = 1
+                    # store the current samples as onset for the next event
+                    prev_onset = r
+
+                # update the reference combination
+                old_comb = comb
+            else:
+                # current event is lasting
+                duration += 1
+
+        # push the last event in the pipeline
+        if not old_comb is None:
+            events.append(
+                Event(onset=prev_onset, duration=duration,
+                      label=old_comb[0], chunk=old_comb[1], **kwargs))
+
+        return events
+
+
     nsamples = property(fget=getNSamples)
 
 
@@ -550,19 +616,19 @@ def labels2chunks(labels, method="alllabels", ignore_labels=None):
     chunks = []
     if ignore_labels is None:
         ignore_labels = []
-    alllabels = Set(labels).difference(Set(ignore_labels))
+    alllabels = set(labels).difference(set(ignore_labels))
     if method == 'alllabels':
-        seenlabels = Set()
+        seenlabels = set()
         lastlabel = None
         chunk = 0
         for label in labels:
             if label != lastlabel:
                 if seenlabels == alllabels:
                     chunk += 1
-                    seenlabels = Set()
+                    seenlabels = set()
                 lastlabel = label
                 if not label in ignore_labels:
-                    seenlabels.union_update([label])
+                    seenlabels.update([label])
             chunks.append(chunk)
         chunks = N.array(chunks)
         # fix up a bit the trailer
