@@ -1,5 +1,5 @@
-#emacs: -*- mode: python-mode; py-indent-offset: 4; indent-tabs-mode: nil -*-
-#ex: set sts=4 ts=4 sw=4 et:
+# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
+# vi: set ft=python sts=4 ts=4 sw=4 et:
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 #
 #   See COPYING file distributed along with the PyMVPA package for the
@@ -10,11 +10,17 @@
 
 __docformat__ = 'restructuredtext'
 
+import re
+import textwrap
 from mvpa.misc.state import CollectableAttribute
 
 if __debug__:
     from mvpa.base import debug
 
+_whitespace_re = re.compile('\n\s+|^\s+')
+
+__all__ = [ 'Parameter', 'KernelParameter' ]
+
 class Parameter(CollectableAttribute):
     """This class shall serve as a representation of a parameter.
 
@@ -37,7 +43,7 @@ class Parameter(CollectableAttribute):
         step  - increment/decrement stepsize
     """
 
-    def __init__(self, default, name=None, doc=None, **kwargs):
+    def __init__(self, default, name=None, doc=None, index=None, **kwargs):
         """Specify a parameter by its default value and optionally an arbitrary
         number of additional parameters.
 
@@ -45,7 +51,7 @@ class Parameter(CollectableAttribute):
         """
         self.__default = default
 
-        CollectableAttribute.__init__(self, name, doc)
+        CollectableAttribute.__init__(self, name=name, doc=doc, index=index)
 
         self.resetvalue()
         self._isset = False
@@ -66,6 +72,38 @@ class Parameter(CollectableAttribute):
         return res
 
 
+    def doc(self, indent="  ", width=70):
+        """Docstring for the parameter to be used in lists of parameters
+
+        :Returns:
+          string or list of strings (if indent is None)
+        """
+        paramsdoc = "  %s" % self.name
+        if hasattr(paramsdoc, 'allowedtype'):
+            paramsdoc += " : %s" % self.allowedtype
+        paramsdoc = [paramsdoc]
+        try:
+            doc = self.__doc__
+            if not doc.endswith('.'): doc += '.'
+            try:
+                doc += " (Default: %s)" % self.default
+            except:
+                pass
+            # Explicitly deal with multiple spaces, for some reason
+            # replace_whitespace is non-effective
+            doc = _whitespace_re.sub(' ', doc)
+            paramsdoc += ['  ' + x
+                          for x in textwrap.wrap(doc, width=width-len(indent),
+                                                 replace_whitespace=True)]
+        except Exception, e:
+            pass
+
+        if indent is None:
+            return paramsdoc
+        else:
+            return ('\n' + indent).join(paramsdoc)
+
+
     # XXX should be named reset2default? correspondingly in
     #     ParameterCollection as well
     def resetvalue(self):
