@@ -18,7 +18,6 @@ It was devised to provide conditional storage
 __docformat__ = 'restructuredtext'
 
 import operator, copy
-from sets import Set
 from textwrap import TextWrapper
 
 import numpy as N
@@ -150,7 +149,7 @@ class Collection(object):
         """Initialize `index` (no check performed) with `value`
         """
         # by default we just set corresponding value
-        self.setvalue(index, value)
+        self[index].value = value
 
 
     def __repr__(self):
@@ -214,12 +213,6 @@ class Collection(object):
         return self._items.has_key(index)
 
 
-    def __isSet1(self, index):
-        """Returns `True` if state `index` has value set"""
-        self._checkIndex(index)
-        return self._items[index].isSet
-
-
     def isSet(self, index=None):
         """If item (or any in the present or listed) was set
 
@@ -281,18 +274,21 @@ class Collection(object):
 
               Also we might convert to __setitem__
         """
+        # local binding
+        name = item.name
         if not isinstance(item, CollectableAttribute):
             raise ValueError, \
                   "Collection can add only instances of " + \
                   "CollectableAttribute-derived classes. Got %s" % `item`
-        if item.name is None:
+
+        if name is None:
             raise ValueError, \
                   "CollectableAttribute to be added %s must have 'name' set" % \
                   item
-        self._items[item.name] = item
+        self._items[name] = item
 
         if not self.owner is None:
-            self._updateOwner(item.name)
+            self._updateOwner(name)
 
 
     def remove(self, index):
@@ -347,12 +343,6 @@ class Collection(object):
     #    _object_setattr(self, index, value)
 
 
-    def getvalue(self, index):
-        """Returns the value by index"""
-        self._checkIndex(index)
-        return self._items[index].value
-
-
     def get(self, index, default):
         """Access the value by a given index.
 
@@ -368,12 +358,6 @@ class Collection(object):
             #    raise e
 
 
-    def setvalue(self, index, value):
-        """Sets the value by index"""
-        self._checkIndex(index)
-        self._items[index].value = value
-
-
     def _action(self, index, func, missingok=False, **kwargs):
         """Run specific func either on a single item or on all of them
 
@@ -725,8 +709,8 @@ class StateCollection(Collection):
         if not other is None:
             # lets take states which are enabled in other but not in
             # self
-            add_enable_states = list(Set(other.enabled).difference(
-                 Set(enable_states)).intersection(self.names))
+            add_enable_states = list(set(other.enabled).difference(
+                 set(enable_states)).intersection(self.names))
             if len(add_enable_states)>0:
                 if __debug__:
                     debug("ST",
@@ -855,7 +839,11 @@ class AttributesCollector(type):
                 collections[col][name] = value
                 # and assign name if not yet was set
                 if value.name is None:
-                    value.name = name
+                    value._setName(name)
+                # !!! We do not keep copy of this attribute static in the class.
+                #     Due to below traversal of base classes, we should be
+                #     able to construct proper collections even in derived classes
+                delattr(cls, name)
 
         # XXX can we first collect parent's states and then populate with ours?
         # TODO
@@ -1096,7 +1084,7 @@ class ClassWithCollections(object):
         # check if it is a part of any collection
         known_attribs = s_dict['_known_attribs']
         if index in known_attribs:
-            return collections[known_attribs[index]].getvalue(index)
+            return collections[known_attribs[index]]._items[index].value
 
         # just a generic return
         return _object_getattribute(self, index)
@@ -1111,7 +1099,8 @@ class ClassWithCollections(object):
         known_attribs = s_dict['_known_attribs']
         if index in known_attribs:
             collections = s_dict['_collections']
-            return collections[known_attribs[index]].setvalue(index, value)
+            collections[known_attribs[index]][index].value = value
+            return value
 
         # Generic setattr
         return _object_setattr(self, index, value)
