@@ -250,8 +250,11 @@ class DistPValue(ClassWithCollections):
         shape_orig = x.shape
         ndims = len(shape_orig)
 
-        # XXX for now deal with numpy deprecation hell locally:
-        hist_kwargs = ({}, {'new': False})[externals.versions['numpy'] > (1,1)]
+        # (very) old numpy had different format of returned bins --
+        # there were not edges but center points.  We care here about
+        # center points, so we will transform edge points into center
+        # points for newer versions of numpy
+        numpy_center_points = externals.versions['numpy'] < (1, 1)
 
         # XXX May be just utilize OverAxis transformer?
         if ndims > 2:
@@ -273,21 +276,25 @@ class DistPValue(ClassWithCollections):
             if nd < x.shape[0]:
                 warning("Number of features in DistPValue lower than number of"
                         " items -- may be incorrect sd=%d was provided" % sd)
-        dist = stats.rdist(nd-1, 0, 1)
         for i, xx in enumerate(x):
+            dist = stats.rdist(nd-1, 0, 1)
             xx /= N.linalg.norm(xx)
 
             if fpp is not None:
+                if __debug__:
+                    debug('TRAN_', "starting adaptive adjustment i=%d" % i)
+
                 # Adaptive adjustment for false negatives:
                 Nxx, xxx, pN_emp_prev = len(xx), xx, 1.0
                 Nxxx = Nxx
                 indexes = N.arange(Nxx)
                 """What features belong to Null-distribution"""
                 while True:
-                    Nhist = N.histogram(xxx, bins=nbins, normed=False,
-                                        **hist_kwargs)
-                    pdf = Nhist[0].astype(float)/Nxxx
-                    bins = Nhist[1]
+                    hist, bins = N.histogram(xxx, bins=nbins, normed=False)
+                    pdf = hist.astype(float)/Nxxx
+                    if not numpy_center_points:
+                        # if we obtain edge points for bins -- take centers
+                        bins = 0.5 * (bins[0:-1] + bins[1:])
                     bins_halfstep = (bins[1] - bins[2])/2.0
 
                     # theoretical CDF
@@ -358,7 +365,7 @@ class DistPValue(ClassWithCollections):
 
                 if __debug__:
                     if  distribution == 'rdist':
-                        assert(dist.args[0], Nindexes-1)
+                        assert(dist.args[0] == Nindexes-1)
                     debug('TRAN', "Positives recovery finished with %d out of %d "
                           "entries in Null-distribution, thus %d positives "
                           "were recovered" % (Nindexes, Nxx, Nrecovered))
