@@ -44,7 +44,6 @@ def collectTestSuites():
         'test_stats',
         'test_support',
         'test_verbosity',
-        'test_iohelpers',
         'test_report',
         'test_datasetfx',
         'test_cmdline',
@@ -99,6 +98,7 @@ def collectTestSuites():
                          ('scipy', 'zscoremapper'),
                          ('pywt', 'waveletmapper'),
                          (['cPickle', 'gzip'], 'hamster'),
+                         ('nose', 'iohelpers'),
     #                     ('mdp', 'pcamapper'),
                        ]
 
@@ -119,6 +119,10 @@ def collectTestSuites():
 
     # import all test modules
     for t in tests:
+
+        # TODO: exclude tests which fail to import: e.g. on Windows
+        # could get WindowsError due to missing msvcr90.dll
+
         exec 'import ' + t
 
     # instanciate all tests suites and return dict of them (with ID as key)
