@@ -8,8 +8,6 @@
 ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 """Unit tests for SVM classifier"""
 
-from sets import Set
-
 from mvpa.datasets.splitters import NFoldSplitter
 from mvpa.clfs.meta import ProxyClassifier
 from mvpa.clfs.transerror import TransferError
@@ -44,8 +42,8 @@ class SVMTests(unittest.TestCase):
         #                     [nl_param_orig[k] for k in orig_keys],
         #   msg="New instance mustn't override values in previously created")
         ## and keys separately
-        #self.failUnlessEqual(Set(nl_clf.param._params.keys()),
-        #                     Set(orig_keys),
+        #self.failUnlessEqual(set(nl_clf.param._params.keys()),
+        #                     set(orig_keys),
         #   msg="New instance doesn't change set of parameters in original")
 
         # We must be able to deepcopy not yet trained SVMs now
@@ -139,6 +137,9 @@ class SVMTests(unittest.TestCase):
             #print "D:", cve.confusion.stats["P'"][1], cve.confusion.stats['MCC'][1]
 
         # Set '1 C per label'
+        # recreate cvte since previous might have operated on copies
+        cve = CrossValidatedTransferError(TransferError(clf), NFoldSplitter(),
+                                          enable_states='confusion')
         oldC = clf.C
         ratio = N.sqrt(float(spl[0])/spl[1])
         clf.C = (-1/ratio, -1*ratio)
