@@ -13,14 +13,13 @@ from StringIO import StringIO
 
 from mvpa.base.verbosity import OnceLogger
 
-from mvpa.base import verbose
+from mvpa.base import verbose, error
 
 if __debug__:
     from mvpa.base import debug
     debug.register('1', 'id 1')           # needed for testing
     debug.register('2', 'id 2')
 
-    from sets import Set
 
 ## XXX There must be smth analogous in python... don't know it yet
 # And it is StringIO
@@ -128,6 +127,12 @@ class VerboseOutputTest(unittest.TestCase):
         self.failUnlessEqual(self.sout.getvalue(), self.msg+"\nXXX\nXXX\n")
 
 
+    def testError(self):
+        """Test error message"""
+        error(self.msg, critical=False) # should not exit
+        self.failUnless(self.sout.getvalue().startswith("ERROR"))
+
+
     if __debug__:
         def testDebug(self):
             verbose.handlers = []           # so debug doesn't spoil it
@@ -147,14 +152,14 @@ class VerboseOutputTest(unittest.TestCase):
             verbose.handlers = []           # so debug doesn't spoil it
             debug.active = ['.*']
             # we should have enabled all of them
-            self.failUnlessEqual(Set(debug.active),
-                                 Set(debug.registered.keys()))
+            self.failUnlessEqual(set(debug.active),
+                                 set(debug.registered.keys()))
             debug.active = ['S.*', 'CLF']
-            self.failUnlessEqual(Set(debug.active),
-                                 Set(filter(lambda x:x.startswith('S'),
+            self.failUnlessEqual(set(debug.active),
+                                 set(filter(lambda x:x.startswith('S'),
                                             debug.registered.keys())+['CLF']))
             debug.active = ['SG', 'CLF']
-            self.failUnlessEqual(Set(debug.active), Set(['SG', 'CLF']),
+            self.failUnlessEqual(set(debug.active), set(['SG', 'CLF']),
                                  msg="debug should do full line matching")
 
             debug.offsetbydepth = True
